==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/en_GB.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "You cannot remove your own read permission.",
    "Team folders" : "Team folders",
    "Admin configured folders shared with everyone in a team" : "Admin configured folders shared with everyone in a team",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder.",
    "Unset" : "Unset",
    "Denied (Inherited permission)" : "Denied (Inherited permission)",
    "Allowed (Inherited permission)" : "Allowed (Inherited permission)",
    "Denied" : "Denied",
    "Allowed" : "Allowed",
    "Access denied" : "Access denied",
    "Access allowed" : "Access allowed",
    "Inherit permission" : "Inherit permission",
    "Deny" : "Deny",
    "Allow" : "Allow",
    "Group" : "Group",
    "Team" : "Team",
    "Team folder" : "Team folder",
    "Read" : "Read",
    "Write" : "Write",
    "Create" : "Create",
    "Delete" : "Delete",
    "Share" : "Share",
    "You" : "You",
    "Remove access rule" : "Remove access rule",
    "Add advanced permission rule" : "Add advanced permission rule",
    "Select a user or group" : "Select a user or group",
    "Open Team folder" : "Open Team folder",
    "Permission denied. User does not have sufficient permissions." : "Permission denied. User does not have sufficient permissions.",
    "Unexpected status from server" : "Unexpected status from server",
    "List of Team folders." : "List of Team folders.",
    "No Team folders yet" : "No Team folders yet",
    "Team folders will show up here" : "Team folders will show up here",
    "Add group" : "Add group",
    "Default" : "Default",
    "Unlimited" : "Unlimited",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone",
    "Delete \"{folderName}\"?" : "Delete \"{folderName}\"?",
    "Team folder admin delegation" : "Team folder admin delegation",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud allows you to delegate the administration of Team folders to non-admin users.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Specify below the groups that will be allowed to manage Team folders and use its API/REST.",
    "They will have access to all Team folders." : "They will have access to all Team folders.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Specify below the groups that will be allowed to manage Team folders and use its API/REST only.",
    "They will only have access to Team folders for which they have advanced permissions." : "They will only have access to Team folders for which they have advanced permissions.",
    "Group or team" : "Group or team",
    "Sort by number of groups or teams that have access to this folder" : "Sort by number of groups or teams that have access to this folder",
    "Sort by number of groups that have access to this folder" : "Sort by number of groups that have access to this folder",
    "Folder name" : "Folder name",
    "Quota" : "Quota",
    "Advanced Permissions" : "Advanced Permissions",
    "Pagination of team folders" : "Pagination of team folders",
    "Previous" : "Previous",
    "Next" : "Next",
    "User" : "User",
    "Unknown" : "Unknown",
    "Users/groups that can manage" : "Users/groups that can manage",
    "None" : "None",
    "No other groups or teams available" : "No other groups or teams available",
    "No other groups available" : "No other groups available",
    "{displayName} (team)" : "{displayName} (team)",
    "Add group or team" : "Add group or team",
    "{size} used" : "{size} used",
    "Other …" : "Other …",
    "You can not remove your own read permission." : "You can not remove your own read permission.",
    "Group folders" : "Group folders",
    "Admin configured folders shared with everyone in a group" : "Admin configured folders shared with everyone in a group",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder.",
    "Group folder" : "Group folder",
    "Open group folder" : "Open group folder",
    "List of group folders." : "List of group folders.",
    "No group folders yet" : "No group folders yet",
    "Group folders will show up here" : "Group folders will show up here",
    "Group folder admin delegation" : "Group folder admin delegation",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud allows you to delegate the administration of group folders to non-admin users.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Specify below the groups that will be allowed to manage group folders and use its API/REST.",
    "They will have access to all group folders." : "They will have access to all group folders.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Specify below the groups that will be allowed to manage group folders and use its API/REST only.",
    "They will only have access to group folders for which they have advanced permissions." : "They will only have access to group folders for which they have advanced permissions.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder."
},
"nplurals=2; plural=(n != 1);");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/en_GB.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "You cannot remove your own read permission.",
    "Team folders" : "Team folders",
    "Unset" : "Unset",
    "Denied (Inherited permission)" : "Denied (Inherited permission)",
    "Allowed (Inherited permission)" : "Allowed (Inherited permission)",
    "Denied" : "Denied",
    "Allowed" : "Allowed",
    "Access denied" : "Access denied",
    "Access allowed" : "Access allowed",
    "Inherit permission" : "Inherit permission",
    "Deny" : "Deny",
    "Allow" : "Allow",
    "Group" : "Group",
    "Team" : "Team",
    "Team folder" : "Team folder",
    "Read" : "Read",
    "Write" : "Write",
    "Create" : "Create",
    "Delete" : "Delete",
    "Share" : "Share",
    "You" : "You",
    "Remove access rule" : "Remove access rule",
    "Add advanced permission rule" : "Add advanced permission rule",
    "Select a user or group" : "Select a user or group",
    "Open Team folder" : "Open Team folder",
    "Permission denied. User does not have sufficient permissions." : "Permission denied. User does not have sufficient permissions.",
    "Unexpected status from server" : "Unexpected status from server",
    "List of Team folders." : "List of Team folders.",
    "No Team folders yet" : "No Team folders yet",
    "Team folders will show up here" : "Team folders will show up here",
    "Add group" : "Add group",
    "Default" : "Default",
    "Unlimited" : "Unlimited",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone",
    "Delete \"{folderName}\"?" : "Delete \"{folderName}\"?",
    "Team folder admin delegation" : "Team folder admin delegation",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud allows you to delegate the administration of Team folders to non-admin users.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Specify below the groups that will be allowed to manage Team folders and use its API/REST.",
    "They will have access to all Team folders." : "They will have access to all Team folders.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Specify below the groups that will be allowed to manage Team folders and use its API/REST only.",
    "They will only have access to Team folders for which they have advanced permissions." : "They will only have access to Team folders for which they have advanced permissions.",
    "Group or team" : "Group or team",
    "Sort by number of groups or teams that have access to this folder" : "Sort by number of groups or teams that have access to this folder",
    "Sort by number of groups that have access to this folder" : "Sort by number of groups that have access to this folder",
    "Folder name" : "Folder name",
    "Quota" : "Quota",
    "Advanced Permissions" : "Advanced Permissions",
    "Pagination of team folders" : "Pagination of team folders",
    "Previous" : "Previous",
    "Next" : "Next",
    "User" : "User",
    "Unknown" : "Unknown",
    "Users/groups that can manage" : "Users/groups that can manage",
    "None" : "None",
    "No other groups or teams available" : "No other groups or teams available",
    "No other groups available" : "No other groups available",
    "{displayName} (team)" : "{displayName} (team)",
    "Add group or team" : "Add group or team",
    "{size} used" : "{size} used",
    "Other …" : "Other …",
    "You can not remove your own read permission." : "You can not remove your own read permission.",
    "Group folders" : "Group folders",
    "Admin configured folders shared with everyone in a group" : "Admin configured folders shared with everyone in a group",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder.",
    "Group folder" : "Group folder",
    "Open group folder" : "Open group folder",
    "List of group folders." : "List of group folders.",
    "No group folders yet" : "No group folders yet",
    "Group folders will show up here" : "Group folders will show up here",
    "Group folder admin delegation" : "Group folder admin delegation",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud allows you to delegate the administration of group folders to non-admin users.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Specify below the groups that will be allowed to manage group folders and use its API/REST.",
    "They will have access to all group folders." : "They will have access to all group folders.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Specify below the groups that will be allowed to manage group folders and use its API/REST only.",
    "They will only have access to group folders for which they have advanced permissions." : "They will only have access to group folders for which they have advanced permissions.",
    "Admin configured folders shared with everyone in a team" : "Admin configured folders shared with everyone in a team",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder."
},
"nplurals=2; plural=(n != 1);");
